Re: Proposed ATK Role additions



I propose the following patch to atkobject.h to define the following roles.
If you have any objections, please speak quickly.

This is based on Marc's mail and Peter's and Bill's replies.

I have not added ATK_ROLE_DIAL as I did not find the widget GtkDial; is this a 
typo? If so, do you have a one-line description of it?

I did not add ATK_ROLE_CHECK_MENU_ITEM and ATK_ROLE_RADIO_MENU_ITEM as we 
already have ATK_ROLE_CHECK_BOX and ATK_ROLE_RADIO_BUTTON. Should I rename the 
existing roles?

I removed the role ATK_ROLE_FOCUS_TRAVERSABLE sa it did not look like a valid 
role.

Padraig

===================================================================
RCS file: /cvs/gnome/atk/atk/atkobject.h,v
retrieving revision 1.6
diff -u -p -r1.6 atkobject.h
--- atkobject.h 2001/05/09 17:21:05     1.6
+++ atkobject.h 2001/05/10 08:28:26
@@ -44,9 +44,17 @@ typedef enum
 typedef enum
 {
   ATK_ROLE_INVALID,
-  /* Object is used to alert the user about something */
+  /* A label which represents an accelerator */
+  ATK_ROLE_ACCEL_LABEL,
+  /* An object is used to alert the user about something */
   ATK_ROLE_ALERT,
-  /* Object that can be drawn into and is sued to trap events */
+  /* An object which is an animated image */
+  ATK_ROLE_ANIMATION,
+  /* An arrow in one of the four cardinal directoions */
+  ATK_ROLE_ARROW,
+  /* An object that displays a calendar and allows the user to select a date */
+  ATK_ROLE_CALENDAR,
+  /* An object that can be drawn into and is used to trap events */
   ATK_ROLE_CANVAS,
   /*
    * A choice that can be checked or unchecked and provides a separate
@@ -59,6 +67,8 @@ typedef enum
   ATK_ROLE_COLUMN_HEADER,
   /* A list of choices the user can select from */
   ATK_ROLE_COMBO_BOX,
+  /* An object whose purpose is to allow a user to edit a date */
+  ATK_ROLE_DATE_EDITOR,
   /* An inconifed internal frame within a DESKTOP_PANE */
   ATK_ROLE_DESKTOP_ICON,
   /*
@@ -78,13 +88,14 @@ typedef enum
    * the user select a file, browse a different directory, or specify a
    * filename.
    */
+  /* An object used for drawing custom user interface elements */
+  ATK_ROLE_DRAWING_AREA,
+  /* A specialized dialog that lets the user choose a file. */
   ATK_ROLE_FILE_CHOOSER,
-  /*
-   * A object that fills up space in a user interface
-   */
+  /* A object that fills up space in a user interface */
   ATK_ROLE_FILLER,
-  /* XXX Don't know sure about this. */
-  ATK_ROLE_FOCUS_TRAVERSABLE,
+  /* A specialized dialog that lets the user choose a font. */
+  ATK_ROLE_FONT_CHOOSER,
   /* A top level window with a title bar, border, menubar, etc. */
   ATK_ROLE_FRAME,
   /* A pane that is guaranteed to be painted on top of all panes beneath it */
@@ -96,6 +107,8 @@ typedef enum
   ATK_ROLE_HTML_CONTAINER,
   /* A small fixed size picture, typically used to decorate components */
   ATK_ROLE_ICON,
+  /* An object whose primary purpose is to display an image */
+  ATK_ROLE_IMAGE,
   /* A frame-like object that is clipped by a desktop pane. */
   ATK_ROLE_INTERNAL_FRAME,
   /* An object used to present an icon or short string in an interface */
@@ -186,11 +199,17 @@ typedef enum
   ATK_ROLE_SLIDER,
   /* A specialized panel that presents two other panels at the same time. */
   ATK_ROLE_SPLIT_PANE,
+  /* An object used to get an integer or floating point number from the user */
+  ATK_ROLE_SPIN_BUTTON,
+  /* An object which reports messages of minor importance to the user */
+  ATK_STATUS_BAR,
   /* An object used to rpesent information in terms of rows and columns. */
   ATK_ROLE_TABLE,
   ATK_ROLE_TABLE_CELL,
   ATK_ROLE_TABLE_COLUMN_HEADER,
   ATK_ROLE_TABLE_ROW_HEADER,
+  /* A menu item used to tear off and reattach its menu */
+  ATK_ROLE_TEAR_OFF_MENU_ITEM,
   /* An object that presents text to the user */
   ATK_ROLE_TEXT,
   /*


> Delivered-To: gnome-accessibility-list gnome org
> X-Sender: mm128299 bes central sun com
> To: gnome-accessibility-list gnome org
> Subject: Proposed ATK Role additions
> Mime-Version: 1.0
> X-BeenThere: gnome-accessibility-list gnome org
> X-Loop: gnome-accessibility-list gnome org
> X-Mailman-Version: 2.0beta5
> List-Id: GNOME accessibility development <gnome-accessibility-list.gnome.org>
> 
> Hi All,
> 
> Based on my GTK Widgets and Gnomeui documents, I came up with the attached 
> list of roles which appear to be missing from ATK.  Comments please.
> 
> Regards,
> 
> Marc





[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]